// Copyright (c) 2020-2023 by the Zeek Project. See LICENSE for details.

#pragma once

#include <spicy/compiler/detail/codegen/productions/boolean.h>
#include <spicy/compiler/detail/codegen/productions/counter.h>
#include <spicy/compiler/detail/codegen/productions/ctor.h>
#include <spicy/compiler/detail/codegen/productions/deferred.h>
#include <spicy/compiler/detail/codegen/productions/enclosure.h>
#include <spicy/compiler/detail/codegen/productions/epsilon.h>
#include <spicy/compiler/detail/codegen/productions/for-each.h>
#include <spicy/compiler/detail/codegen/productions/look-ahead.h>
#include <spicy/compiler/detail/codegen/productions/reference.h>
#include <spicy/compiler/detail/codegen/productions/sequence.h>
#include <spicy/compiler/detail/codegen/productions/skip.h>
#include <spicy/compiler/detail/codegen/productions/switch.h>
#include <spicy/compiler/detail/codegen/productions/type-literal.h>
#include <spicy/compiler/detail/codegen/productions/unit.h>
#include <spicy/compiler/detail/codegen/productions/variable.h>
#include <spicy/compiler/detail/codegen/productions/while.h>
